@@ -1,30 +1,43 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
-#include <dune/istl/bvector.hh>
-#include <dune/common/fvector.hh>
-#include <dune/common/poolallocator.hh>
+
+// hack to ensure assert() does something
+// really, assert() should not be used in unit tests.
+#ifdef NDEBUG
+#undef NDEBUG
+#endif
+
+#include <cassert>
+#include <cmath>
+#include <complex>
+#include <cstdlib>
+#include <iostream>
+#include <memory>
+
+#include <dune/common/classname.hh>
 #if HAVE_MPROTECT
 #include <dune/common/debugallocator.hh>
 #endif
-#include <dune/common/classname.hh>
+#include <dune/common/deprecated.hh>
+#include <dune/common/fvector.hh>
+#include <dune/common/poolallocator.hh>
+#include <dune/common/scalarvectorview.hh>
 
+#include <dune/istl/bvector.hh>
 #include <dune/istl/test/vectortest.hh>
 
-template<typename T, int BS>
-void assign(Dune::FieldVector<T,BS>& b, const T& i)
+template<typename VectorBlock, typename V>
+void assign(VectorBlock& b, const V& i)
 {
-
-  for(int j=0; j < BS; j++)
-    b[j] = i;
+  for (auto& entry : Dune::Impl::asVector(b))
+    entry = i;
 }
 
 
-template<int BS, class A=std::allocator<void> >
+template<class VectorBlock, class A=std::allocator<void> >
 int testVector()
 {
-
-  typedef Dune::FieldVector<double,BS> VectorBlock;
   typedef typename A::template rebind<VectorBlock>::other Alloc;
   typedef Dune::BlockVector<VectorBlock, Alloc> Vector;
 
@@ -58,7 +71,6 @@ int testVector()
   testScalarProduct(v);
 
   assert(w.N()==v.N());
-  assert(w.capacity()==v.capacity());
 
   for(typename Vector::size_type i=0; i < v.N(); ++i)
     assert(v[i] == w[i]);
@@ -79,19 +91,7 @@ int testVector()
 
   // check the entries
   for(typename Vector::size_type i=0; i < v.N(); ++i) {
-    assign(b, (typename VectorBlock::field_type)i);
-    assert(v[i] == b);
-  }
-
-  // Try to shrink the vector
-  v.reserve(v.N());
-
-  assert(v.N()==v.capacity());
-
-  // check the entries
-
-  for(typename Vector::size_type i=0; i < v.N(); ++i) {
-    assign(b,(typename VectorBlock::field_type)i);
+    assign(b, i);
     assert(v[i] == b);
   }
 
@@ -108,12 +108,14 @@ void testCapacity()
   for(int i=0; i<10; ++i)
     vec[i]=Dune::BlockVector<SmallVector>(10);
   ThreeLevelVector vec1=vec;
+DUNE_NO_DEPRECATED_BEGIN
   vec.reserve(20, true);
   vec.reserve(10, true);
   vec.reserve(5, false);
   vec.reserve(20, false);
   vec.reserve(0, true);
   vec1.reserve(0, false);
+DUNE_NO_DEPRECATED_END
 }
 
 template <class V>
@@ -223,17 +225,20 @@ int main()
 
   int ret = 0;
 
-  ret += testVector<1>();
+  ret += testVector<Dune::FieldVector<double,1> >();
   //  ret += testVector<1, Dune::PoolAllocator<void,1000000> >();
 #if HAVE_MPROTECT
-  ret += testVector<1, Dune::DebugAllocator<void> >();
+  ret += testVector<Dune::FieldVector<double,1> , Dune::DebugAllocator<void> >();
 #endif
-  ret += testVector<3>();
+  ret += testVector<Dune::FieldVector<double,3> >();
   //  ret += testVector<3, Dune::PoolAllocator<void,1000000> >();
 #if HAVE_MPROTECT
-  ret += testVector<3, Dune::DebugAllocator<void> >();
+  ret += testVector<Dune::FieldVector<double,1> , Dune::DebugAllocator<void> >();
 #endif
 
+  ret += testVector<double>();
+  ret += testVector<std::complex<double> >();
+
   testCapacity();
 
   return ret;
