@@ -1,10 +1,13 @@
 #include <config.h>
 #include <iostream>
 
+#include <dune/common/deprecated.hh>
 #include <dune/common/fmatrix.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/exceptions.hh>
 
+#include <dune/common/simd/loop.hh>
+
 #include <dune/istl/bvector.hh>
 #include <dune/istl/bcrsmatrix.hh>
 #include <dune/istl/io.hh>
@@ -13,12 +16,10 @@
 
 #include "hilbertmatrix.hh"
 
-template< template< class, class, class, int ... > class _Prec, class K = double, int N = 1 >
+
+template< template< class, class, class, int ... > class _Prec, class MatrixBlock, class VectorBlock >
 void testDecomposition ( int n )
 {
-  using MatrixBlock = Dune::FieldMatrix< K, N, N >;
-  using VectorBlock = Dune::FieldVector< K, N >;
-
   using BlockMatrix = Dune::BCRSMatrix< MatrixBlock >;
   using BlockVector = Dune::BlockVector< VectorBlock >;
 
@@ -40,7 +41,7 @@ void testDecomposition ( int n )
     prec.post( x );
 
     y -= x;
-    if ( y.two_norm() > 1e-8 )
+    if ( Dune::Simd::anyTrue(y.two_norm() > 1e-8) )
       DUNE_THROW( Dune::Exception, "Method Prec::apply() returned wrong value!");
   }
 }
@@ -48,8 +49,15 @@ void testDecomposition ( int n )
 
 int main(int argc, char** argv)
 try {
-  testDecomposition< Dune::SeqILDL, double, 1 >( 4 );
-  testDecomposition< Dune::SeqILU0, double, 1 >( 4 );
+
+  testDecomposition< Dune::SeqILDL, double, double >( 4 );
+  testDecomposition< Dune::SeqILU, double, double >( 4 );
+  testDecomposition< Dune::SeqILDL, Dune::FieldMatrix<double,1,1>, Dune::FieldVector<double,1> >( 4 );
+DUNE_NO_DEPRECATED_BEGIN // for deprecated SeqILU0
+  testDecomposition< Dune::SeqILU0, Dune::FieldMatrix<double,1,1>, Dune::FieldVector<double,1> >( 4 );
+DUNE_NO_DEPRECATED_END // for deprecated SeqILU0
+  testDecomposition< Dune::SeqILU, Dune::FieldMatrix<double,1,1>, Dune::FieldVector<double,1> >( 4 );
+  testDecomposition<Dune::SeqILU, Dune::LoopSIMD<double, 4>, Dune::LoopSIMD<double, 4>>( 4 );
 
   return 0;
 }
